# decoupler-GPU: `dcg`

{mod}`decoupler.mt` contains different statistical methods to extract biological activities {cite}`Badia2022`.
{mod}`rapids_singlecell.dcg` accelerates some of these methods.

```{eval-rst}
.. module:: rapids_singlecell.dcg
.. currentmodule:: rapids_singlecell

.. autosummary::
    :toctree: generated

    dcg.mlm
    dcg.ulm
    dcg.aucell
    dcg.waggr
    dcg.zscore
```
